==> elisa_0.5.8.orig.tar.gz: elisa-0.5.8/elisa/core/tests/test_input_manager.py <==
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

from elisa.core.tests.elisa_test_case import ElisaTestCase
from elisa.base_components.input_provider import PushInputProvider, \
                                                 PollInputProvider
from elisa.core.input_manager import InputManager

class TestInputManager(ElisaTestCase):

    def test_registering_unregister_push(self):
        """
        Check if registering and unregistering a PushInputProvider calls the
        right methods
        """
        
        class SimplePushProvider(PushInputProvider):
            bound = False
            input_manager = None

            def bind(self):
                self.bound = True

            def unbind(self):
                self.bound = False


        s_provider = SimplePushProvider()

        i_manager = InputManager()

        i_manager.register_component(s_provider)

        self.assertTrue(s_provider.bound)
        self.assertEquals(s_provider.input_manager, i_manager)

        i_manager.unregister_component(s_provider)
        self.assertFalse(s_provider.bound)

    def test_register_unregister_poll(self):
        """
        Check if registering and unregistering a PollInputProvider works as
        expected
        """

        class SimplePollProvider(PollInputProvider):
            bound = False
            input_manager = None

            def bind(self):
                self.bound = True

            def unbind(self):
                self.bound = False

        s_provider = SimplePollProvider()

        i_manager = InputManager()

        i_manager.register_component(s_provider)

        # should not be bound!
        self.assertFalse(s_provider.bound)
        self.assertEquals(s_provider.input_manager, None)

        i_manager.unregister_component(s_provider)
        self.assertFalse(s_provider.bound)


    def test_event_processing(self):
        """
        Test if an input event gets forwarded correctly
        """

        input_manager = InputManager()

        def callback(obj, event):
            self.assertEquals(obj, input_manager)
            self.assertEquals(event, '42')
            callback.called = True

        callback.called = False

        input_manager.connect('input_event', callback)
        input_manager.process_event('42')

        self.assertTrue(callback.called)

        
    def test_poll_processing(self):
        """
        test if a polled input events gets triggered correctly
        """

        class SimplePollProvider(PollInputProvider):
            def get_input_events(self):
                return ('pocahontas',)

        input_manager = InputManager()
        
        # tweak the provider:
        def event_call(event):
            self.assertEquals(event, 'pocahontas')
            event_call.called = True

        event_call.called = False

        input_manager.process_event = event_call

        simple = SimplePollProvider()
        input_manager.register_component(simple)

        input_manager._poll_events()

        self.assertTrue(event_call.called)

    def test_corrupted_provider(self):
        """
        check that everything is fine with a corrupted provider
        """
            
        class WrongProvider(object):
            path = 'wrong_provider'
        
        input_manager = InputManager()
        input_manager.register_component(WrongProvider())

        # should filter out only PollProviders, so it shouldn't brake
        input_manager._poll_events()

    def test_processing_breaks(self):
        """
        test what happens, when the signal chain breaks
        """

        def call1(obj, data):
            call1.called = True

        call1.called = False

        def callfails(obj, data):
            callfails.called = True
            raise Exception("No way, dude!")

        callfails.called = False

        def call2(obj, data):
            call2.called = True

        call2.called = False
        
        input_manager = InputManager()
        input_manager.connect('input_event', call1)
        input_manager.connect('input_event', callfails)
        input_manager.connect('input_event', call2)

        input_manager.process_event('yep')

        self.assertTrue(call1.called)
        self.assertTrue(callfails.called)
        self.assertTrue(call2.called)

    def test_start_stop(self):
        """
        test if the poll loop gets set up and stopped on start and stop
        """

        input_manager = InputManager()

        self.assertTrue(input_manager._poll_call is None)

        input_manager.start()
        self.assertFalse(input_manager._poll_call is None)

        input_manager.stop()
        self.assertTrue(input_manager._poll_call.cancelled)

==> elisa_0.5.15.5.orig.tar.gz: elisa-0.5.15.5/elisa/core/tests/test_input_manager.py <==
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

from elisa.core.tests.elisa_test_case import ElisaTestCase
from elisa.core.components.input_provider import PushInputProvider, \
                                                 PollInputProvider
from elisa.core.input_manager import InputManager

class TestInputManager(ElisaTestCase):

    def test_registering_unregister_push(self):
        """
        Check if registering and unregistering a PushInputProvider calls the
        right methods
        """
        
        class SimplePushProvider(PushInputProvider):
            bound = False
            input_manager = None

            def bind(self):
                self.bound = True

            def unbind(self):
                self.bound = False

        s_provider = SimplePushProvider()

        i_manager = InputManager()

        i_manager.register_component(s_provider)

        self.assertTrue(s_provider.bound)
        self.assertEquals(s_provider.input_manager, i_manager)

        i_manager.unregister_component(s_provider)
        self.assertFalse(s_provider.bound)

    def test_register_unregister_poll(self):
        """
        Check if registering and unregistering a PollInputProvider works as
        expected
        """

        class SimplePollProvider(PollInputProvider):
            bound = False
            input_manager = None

            def bind(self):
                self.bound = True

            def unbind(self):
                self.bound = False

        s_provider = SimplePollProvider()

        i_manager = InputManager()

        i_manager.register_component(s_provider)

        # should not be bound!
        self.assertFalse(s_provider.bound)
        self.assertEquals(s_provider.input_manager, None)

        i_manager.unregister_component(s_provider)
        self.assertFalse(s_provider.bound)


    def test_event_processing(self):
        """
        Test if an input event gets forwarded correctly
        """

        input_manager = InputManager()

        def callback(obj, event):
            self.assertEquals(obj, input_manager)
            self.assertEquals(event, '42')
            callback.called = True

        callback.called = False

        input_manager.connect('input_event', callback)
        input_manager.process_event('42')

        self.assertTrue(callback.called)

        
    def test_poll_processing(self):
        """
        test if a polled input events gets triggered correctly
        """

        class SimplePollProvider(PollInputProvider):
            def get_input_events(self):
                return ('pocahontas',)

        input_manager = InputManager()
        
        # tweak the provider:
        def event_call(event):
            self.assertEquals(event, 'pocahontas')
            event_call.called = True

        event_call.called = False

        input_manager.process_event = event_call

        simple = SimplePollProvider()
        input_manager.register_component(simple)

        input_manager._poll_events()

        self.assertTrue(event_call.called)

    def test_corrupted_provider(self):
        """
        check that everything is fine with a corrupted provider
        """
            
        class WrongProvider(object):
            path = 'wrong_provider'
        
        input_manager = InputManager()
        input_manager.register_component(WrongProvider())

        # should filter out only PollProviders, so it shouldn't brake
        input_manager._poll_events()

    def test_processing_breaks(self):
        """
        test what happens, when the signal chain breaks
        """

        def call1(obj, data):
            call1.called = True

        call1.called = False

        def callfails(obj, data):
            callfails.called = True
            raise Exception("No way, dude!")

        callfails.called = False

        def call2(obj, data):
            call2.called = True

        call2.called = False
        
        input_manager = InputManager()
        input_manager.connect('input_event', call1)
        input_manager.connect('input_event', callfails)
        input_manager.connect('input_event', call2)

        input_manager.process_event('yep')

        self.assertTrue(call1.called)
        self.assertTrue(callfails.called)
        self.assertTrue(call2.called)

    def test_start_stop(self):
        """
        test if the poll loop gets set up and stopped on start and stop
        """
        input_manager = InputManager()
        # start condition
        self.assertFalse(input_manager._poll_call.running)

        input_manager.start()
        # no poll providers so polling is not started
        self.assertFalse(input_manager._poll_call.running)
        
        class SimplePollProvider(PollInputProvider):
            def get_input_events(self):
                return ('pocahontas',)

        # add a poll provider, polling should start
        component = SimplePollProvider()
        input_manager.register_component(component)
        self.assertTrue(input_manager._poll_call.running)

        # stop
        input_manager.stop()
        self.assertFalse(input_manager._poll_call.running)
        
        # start again, this time the polling should start as there's a poll
        # provider
        component = SimplePollProvider()
        input_manager.register_component(component)
        input_manager.start()
        self.assertTrue(input_manager._poll_call.running)

        # after removing the last poll provider, polling should stop
        input_manager.unregister_component(component)
        self.assertFalse(input_manager._poll_call.running)
